@@ -15,7 +15,6 @@
 package packages
 
 import (
-	"context"
 	"errors"
 	"os"
 	"os/exec"
@@ -33,19 +32,19 @@ func TestInstallAptPackages(t *testing.T) {
 	mockCommandRunner := utilmocks.NewMockCommandRunner(mockCtrl)
 	runner = mockCommandRunner
 
-	expectedCmd := exec.CommandContext(context.Background(), aptGet, append(aptGetInstallArgs, pkgs...)...)
+	expectedCmd := exec.Command(aptGet, append(aptGetInstallArgs, pkgs...)...)
 	expectedCmd.Env = append(os.Environ(),
 		"DEBIAN_FRONTEND=noninteractive",
 	)
 
-	mockCommandRunner.EXPECT().Run(testCtx, expectedCmd).Return([]byte("stdout"), []byte("stderr"), nil).Times(1)
+	mockCommandRunner.EXPECT().Run(testCtx, utilmocks.EqCmd(expectedCmd)).Return([]byte("stdout"), []byte("stderr"), nil).Times(1)
 	if err := InstallAptPackages(testCtx, pkgs); err != nil {
 		t.Errorf("unexpected error: %v", err)
 	}
 
-	first := mockCommandRunner.EXPECT().Run(testCtx, expectedCmd).Return([]byte("stdout"), dpkgErr, errors.New("error")).Times(1)
-	repair := mockCommandRunner.EXPECT().Run(testCtx, exec.CommandContext(context.Background(), dpkg, dpkgRepairArgs...)).After(first).Return([]byte("stdout"), []byte("stderr"), nil).Times(1)
-	mockCommandRunner.EXPECT().Run(testCtx, expectedCmd).After(repair).Return([]byte("stdout"), []byte("stderr"), errors.New("error")).Times(1)
+	first := mockCommandRunner.EXPECT().Run(testCtx, utilmocks.EqCmd(expectedCmd)).Return([]byte("stdout"), dpkgErr, errors.New("error")).Times(1)
+	repair := mockCommandRunner.EXPECT().Run(testCtx, utilmocks.EqCmd(exec.Command(dpkg, dpkgRepairArgs...))).After(first).Return([]byte("stdout"), []byte("stderr"), nil).Times(1)
+	mockCommandRunner.EXPECT().Run(testCtx, utilmocks.EqCmd(expectedCmd)).After(repair).Return([]byte("stdout"), []byte("stderr"), errors.New("error")).Times(1)
 	if err := InstallAptPackages(testCtx, pkgs); err == nil {
 		t.Errorf("did not get expected error")
 	}
@@ -57,19 +56,19 @@ func TestRemoveAptPackages(t *testing.T) {
 
 	mockCommandRunner := utilmocks.NewMockCommandRunner(mockCtrl)
 	runner = mockCommandRunner
-	expectedCmd := exec.CommandContext(context.Background(), aptGet, append(aptGetRemoveArgs, pkgs...)...)
+	expectedCmd := exec.Command(aptGet, append(aptGetRemoveArgs, pkgs...)...)
 	expectedCmd.Env = append(os.Environ(),
 		"DEBIAN_FRONTEND=noninteractive",
 	)
 
-	mockCommandRunner.EXPECT().Run(testCtx, expectedCmd).Return([]byte("stdout"), []byte("stderr"), nil).Times(1)
+	mockCommandRunner.EXPECT().Run(testCtx, utilmocks.EqCmd(expectedCmd)).Return([]byte("stdout"), []byte("stderr"), nil).Times(1)
 	if err := RemoveAptPackages(testCtx, pkgs); err != nil {
 		t.Errorf("unexpected error: %v", err)
 	}
 
-	first := mockCommandRunner.EXPECT().Run(testCtx, expectedCmd).Return([]byte("stdout"), dpkgErr, errors.New("error")).Times(1)
-	repair := mockCommandRunner.EXPECT().Run(testCtx, exec.CommandContext(context.Background(), dpkg, dpkgRepairArgs...)).After(first).Return([]byte("stdout"), []byte("stderr"), nil).Times(1)
-	mockCommandRunner.EXPECT().Run(testCtx, expectedCmd).After(repair).Return([]byte("stdout"), []byte("stderr"), errors.New("error")).Times(1)
+	first := mockCommandRunner.EXPECT().Run(testCtx, utilmocks.EqCmd(expectedCmd)).Return([]byte("stdout"), dpkgErr, errors.New("error")).Times(1)
+	repair := mockCommandRunner.EXPECT().Run(testCtx, utilmocks.EqCmd(exec.Command(dpkg, dpkgRepairArgs...))).After(first).Return([]byte("stdout"), []byte("stderr"), nil).Times(1)
+	mockCommandRunner.EXPECT().Run(testCtx, utilmocks.EqCmd(expectedCmd)).After(repair).Return([]byte("stdout"), []byte("stderr"), errors.New("error")).Times(1)
 	if err := RemoveAptPackages(testCtx, pkgs); err == nil {
 		t.Errorf("did not get expected error")
 	}
@@ -81,7 +80,7 @@ func TestInstalledDebPackages(t *testing.T) {
 
 	mockCommandRunner := utilmocks.NewMockCommandRunner(mockCtrl)
 	runner = mockCommandRunner
-	expectedCmd := exec.CommandContext(context.Background(), dpkgQuery, dpkgQueryArgs...)
+	expectedCmd := utilmocks.EqCmd(exec.Command(dpkgQuery, dpkgQueryArgs...))
 	data := []byte("foo amd64 1.2.3-4 installed")
 
 	mockCommandRunner.EXPECT().Run(testCtx, expectedCmd).Return(data, []byte("stderr"), nil).Times(1)
@@ -156,8 +155,8 @@ func TestAptUpdates(t *testing.T) {
 
 	mockCommandRunner := utilmocks.NewMockCommandRunner(mockCtrl)
 	runner = mockCommandRunner
-	updateCmd := exec.CommandContext(context.Background(), aptGet, aptGetUpdateArgs...)
-	expectedCmd := exec.CommandContext(context.Background(), aptGet, append(aptGetUpgradableArgs, aptGetUpgradeCmd)...)
+	updateCmd := utilmocks.EqCmd(exec.Command(aptGet, aptGetUpdateArgs...))
+	expectedCmd := utilmocks.EqCmd(exec.Command(aptGet, append(aptGetUpgradableArgs, aptGetUpgradeCmd)...))
 	data := []byte("Inst google-cloud-sdk [245.0.0-0] (246.0.0-0 cloud-sdk-stretch:cloud-sdk-stretch [amd64])")
 
 	first := mockCommandRunner.EXPECT().Run(testCtx, updateCmd).Return(data, []byte("stderr"), nil).Times(1)
@@ -186,7 +185,7 @@ func TestDebPkgInfo(t *testing.T) {
 	mockCommandRunner := utilmocks.NewMockCommandRunner(mockCtrl)
 	runner = mockCommandRunner
 	testPkg := "test.deb"
-	expectedCmd := exec.CommandContext(context.Background(), dpkgDeb, "-I", testPkg)
+	expectedCmd := utilmocks.EqCmd(exec.Command(dpkgDeb, "-I", testPkg))
 	out := []byte(`new Debian package, version 2.0.
 	size 6731954 bytes: control archive=2138 bytes.
 		498 bytes,    12 lines      control
@@ -235,8 +234,8 @@ func TestAllowDowngradesLogic(t *testing.T) {
 
 	mockCommandRunner := utilmocks.NewMockCommandRunner(mockCtrl)
 	runner = mockCommandRunner
-	cmdWithoutAllowDowngradesFlag := exec.CommandContext(context.Background(), aptGet, []string{}...)
-	cmdWithAllowDowngradesFlag := exec.CommandContext(context.Background(), aptGet, []string{"--allow-downgrades"}...)
+	cmdWithoutAllowDowngradesFlag := utilmocks.EqCmd(exec.Command(aptGet, []string{}...))
+	cmdWithAllowDowngradesFlag := utilmocks.EqCmd(exec.Command(aptGet, []string{"--allow-downgrades"}...))
 
 	mockCommandRunner.EXPECT().Run(testCtx, cmdWithoutAllowDowngradesFlag).Return([]byte(""), []byte("E: Packages were downgraded and -y was used without --allow-downgrades.\n"), errors.New("error")).Times(1)
 	stdoutBytes := []byte("stdout")
